@@ -2,12 +2,15 @@
 from masoniteorm.models import Model
 from masoniteorm.scopes import SoftDeletesMixin
 from masonite.authentication import Authenticates
-from src.masonite_permission.mixins.has_roles import HasRoles
+from src.masonite_permission.mixins import (HasPermissions, HasRoles)
 
 
-class User(Model, SoftDeletesMixin, Authenticates, HasRoles):
+class User(Model, SoftDeletesMixin, Authenticates, HasRoles, HasPermissions):
     """User Model."""
 
     __fillable__ = ["name", "email", "password"]
     __hidden__ = ["password"]
     __auth__ = "email"
+
+
+    
\ No newline at end of file
